pygeodesy.geodesicx.gxline._GeodesicLineExact

Package pygeodesy :: Package geodesicx :: Module gxline :: Class _GeodesicLineExact |
[frames] | no frames]

# Class _GeodesicLineExact

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
       gxbases._GeodesicBase --+
                               |
                              _GeodesicLineExact

Known Subclasses:
  - gx.GeodesicLineExact

(INTERNAL) Base class for GeodesicLineExact.

Instance Methods
__init__(self, gX, lat1, lon1, azi1, caps, **name_) (INTERNAL) New `[_]GeodesicLineExact` instance. |
__del__(self) |
Arc(self) Return the arc length to reference point 3 (`degrees` or `NAN`). |
ArcPosition(self, a12, outmask=1929) Find the position on the line given `a12`. |
Distance(self) Return the distance to reference point 3 (`meter` or `NAN`). |
Intersecant2(self, lat0, lon0, radius, tol=1.4901161193847656e-08) Compute the intersection(s) of this geodesic line and a circle. |
PlumbTo(self, lat0, lon0, est=None, tol=1.4901161193847656e-08) Compute the perpendicular intersection of this geodesic line and a geodesic from the given point. |
Position(self, s12, outmask=1929) Find the position on the line given `s12`. |
SetArc(self, a13) Set reference point 3 in terms relative to the first point. |
SetDistance(self, s13) Set reference point 3 in terms relative to the first point. |
toStr(self, **prec_sep_name) Return this `GeodesicLineExact` as string. |
Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| a1 Get the equatorial arc (`degrees`), the arc length between the northward equatorial crossing and the first point.
| equatorarc Get the equatorial arc (`degrees`), the arc length between the northward equatorial crossing and the first point.
| a13 Get the arc length to reference point 3 (`degrees`).
| azi0 Get the equatorial azimuth, the azimuth of this geodesic line as it crosses the equator in a northward direction (`degrees90`).
| equatorazimuth Get the equatorial azimuth, the azimuth of this geodesic line as it crosses the equator in a northward direction (`degrees90`).
| azi0_sincos2 Get the sine and cosine of the equatorial azimuth (2-tuple `(sin, cos)`).
| azi1 Get the azimuth at the first point (compass `degrees`).
| azi1_sincos2 Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`).
| geodesic Get the exact geodesic (GeodesicExact).
| lat1 Get the latitude of the first point (`degrees`).
| lon1 Get the longitude of the first point (`degrees`).
| s13 Get the distance to reference point 3 (`meter` or `NAN`).
Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, gX, lat1, lon1, azi1, caps, **name_) (Constructor) |
(INTERNAL) New `[_]GeodesicLineExact` instance. Overrides: object.__init__

### Arc (self) |
Return the arc length to reference point 3 (`degrees` or `NAN`). See Also: Method SetArc and property a13.

### ArcPosition (self, a12, outmask=1929) |
Find the position on the line given `a12`. Arguments: `a12` - Spherical arc length from the first point to the second point (`degrees`). `outmask` - Bit-or'ed combination of Caps values specifying the quantities to be returned. Returns: A GDict with up to 12 items `lat1, lon1, azi1, lat2, lon2, azi2, m12, a12, s12, M12, M21, S12` with `lat1`, `lon1`, `azi1` and arc length `a12` always included, except when `a12=NAN`. Note: By default, `outmask=STANDARD`, meaning thc `lat1`, `lon1`, `azi1`, `lat2`, `lon2`, `azi2`, `s12` and `a12` entries are returned, except when `a12=NAN`.

### Distance (self) |
Return the distance to reference point 3 (`meter` or `NAN`). See Also: Method SetDistance and property s13.

### Intersecant2 (self, lat0, lon0, radius, tol=1.4901161193847656e-08) |
Compute the intersection(s) of this geodesic line and a circle. Arguments: `lat0` - Latitude of the circle center (`degrees`). `lon0` - Longitude of the circle center (`degrees`). `radius` - Radius of the circle (`meter`, conventionally). `tol` - Convergence tolerance (`scalar`). Returns: 2-Tuple `(P, Q)` with both intersections (representing a geodesic chord), each a GDict from method Position extended to 14 items by `lon0, lat0, azi0, a02, s02, at` with the circle center `lat0`, `lon0`, azimuth `azi0` at, distance `a02` in `degrees` and `s02` in `meter` along the geodesic from the circle center to the intersection `lat2`, `lon2` and the angle `at` between the geodesic and this line at the intersection. The geodesic azimuth at the intersection is `(at + azi2)`. If this geodesic line is tangential to the circle, both points are the same GDict instance. Raises: `IntersectionError` - The circle and this geodesic line do not intersect, no perpencular geodetic intersection or no convergence. `UnitError` - Invalid `radius`.

### PlumbTo (self, lat0, lon0, est=None, tol=1.4901161193847656e-08) |
Compute the perpendicular intersection of this geodesic line and a geodesic from the given point. Arguments: `lat0` - Latitude of the point (`degrees`). `lon0` - Longitude of the point (`degrees`). `est` - Optional, initial estimate for the distance `s12` of the intersection along this geodesic line (`meter`). `tol` - Convergence tolerance (C(meter)). Returns: The intersection point on this geodesic line, a GDict from method Position extended to 14 items `lat1, lon1, azi1, lat2, lon2, azi2, a12, s12, lat0, lon0, azi0, a02, s02, at` with distance `a02` in `degrees` and `s02` in `meter` between the given `lat0, lon0` point and the intersection `lat2, lon2`, azimuth `azi0` at the given point and `at` the (perpendicular) angle between the geodesic and this line at the intersection. The geodesic azimuth at the intersection is `(at + azi2)`. See method Position for further details. See Also: Methods `Intersecant2`, `Intersection` and `Position`.

### Position (self, s12, outmask=1929) |
Find the position on the line given `s12`. Arguments: `s12` - Distance from this this line's first point (`meter`). `outmask` - Bit-or'ed combination of Caps values specifying the quantities to be returned. Returns: A GDict with up to 12 items `lat1, lon1, azi1, lat2, lon2, azi2, m12, a12, s12, M12, M21, S12` with `lat1`, `lon1`, `azi1` and arc length `a12` always included, except when `a12=NAN`. Notes: By default, `outmask=STANDARD`, meaning thc `lat1`, `lon1`, `azi1`, `lat2`, `lon2`, `azi2`, `s12` and `a12` entries are returned, except when `a12=NAN`. This GeodesicLineExact instance must have been constructed with capability `Caps.DISTANCE_IN` set.

### SetArc (self, a13) |
Set reference point 3 in terms relative to the first point. Arguments: `a13` - Spherical arc length from the first to the reference point (`degrees`). Returns: The distance `s13` (`meter`) between the first and the reference point or `NAN`.

### SetDistance (self, s13) |
Set reference point 3 in terms relative to the first point. Arguments: `s13` - Distance from the first to the reference point (`meter`). Returns: The arc length `a13` (`degrees`) between the first and the reference point or `NAN`.

### toStr (self, **prec_sep_name) |
Return this `GeodesicLineExact` as string. Returns: `GeodesicLineExact` (`str`). Overrides: named._Named.toStr See Also: Ellipsoid.toStr for further details.

Property Details

### a1 Get the equatorial arc (`degrees`), the arc length between the northward equatorial crossing and the first point. Get method: a1(self) - Get the equatorial arc (`degrees`), the arc length between the northward equatorial crossing and the first point. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatorarc Get the equatorial arc (`degrees`), the arc length between the northward equatorial crossing and the first point. Get method: a1(self) - Get the equatorial arc (`degrees`), the arc length between the northward equatorial crossing and the first point. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a13 Get the arc length to reference point 3 (`degrees`). Get method: a13(self) - Get the arc length to reference point 3 (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Methods Arc and SetArc.

### azi0 Get the equatorial azimuth, the azimuth of this geodesic line as it crosses the equator in a northward direction (`degrees90`). Get method: azi0(self) - Get the equatorial azimuth, the azimuth of this geodesic line as it crosses the equator in a northward direction (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatorazimuth Get the equatorial azimuth, the azimuth of this geodesic line as it crosses the equator in a northward direction (`degrees90`). Get method: azi0(self) - Get the equatorial azimuth, the azimuth of this geodesic line as it crosses the equator in a northward direction (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi0_sincos2 Get the sine and cosine of the equatorial azimuth (2-tuple `(sin, cos)`). Get method: azi0_sincos2(self) - Get the sine and cosine of the equatorial azimuth (2-tuple `(sin, cos)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi1 Get the azimuth at the first point (compass `degrees`). Get method: azi1(self) - Get the azimuth at the first point (compass `degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi1_sincos2 Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`). Get method: azi1_sincos2(self) - Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesic Get the exact geodesic (GeodesicExact). Get method: geodesic(self) - Get the exact geodesic (GeodesicExact). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat1 Get the latitude of the first point (`degrees`). Get method: lat1(self) - Get the latitude of the first point (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lon1 Get the longitude of the first point (`degrees`). Get method: lon1(self) - Get the longitude of the first point (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### s13 Get the distance to reference point 3 (`meter` or `NAN`). Get method: s13(self) - Get the distance to reference point 3 (`meter` or `NAN`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Methods Distance and SetDistance.